@@ -25,8 +25,8 @@
 #include "ephy-embed.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-type-builtins.h"
-#include "ephy-evince-document-view.h"
 #include "ephy-file-helpers.h"
+#include "ephy-flatpak-utils.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
 
@@ -43,7 +43,6 @@ struct _EphyDownload {
   char *content_type;
 
   gboolean show_notification;
-  gboolean in_document_mode;
 
   EphyDownloadActionType action;
   guint32 start_time;
@@ -440,14 +439,16 @@ ephy_download_do_download_action (EphyDownload          *download,
   switch ((action ? action : download->action)) {
     case EPHY_DOWNLOAD_ACTION_BROWSE_TO:
       LOG ("ephy_download_do_download_action: browse_to");
-      ret = ephy_file_browse_to (destination, user_time);
+      /* Must not use this action type under flatpak! */
+      ret = ephy_file_browse_to (destination, user_time,
+                                 EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
       break;
     case EPHY_DOWNLOAD_ACTION_OPEN:
       LOG ("ephy_download_do_download_action: open");
-      ret = ephy_embed_shell_launch_handler (ephy_embed_shell_get_default (),
-                                             destination, NULL, user_time);
-      if (!ret)
-        ret = ephy_file_browse_to (destination, user_time);
+      ret = ephy_file_launch_handler (destination, user_time);
+      if (!ret && !ephy_is_running_inside_flatpak ())
+        ret = ephy_file_browse_to (destination, user_time,
+                                   EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
       break;
     case EPHY_DOWNLOAD_ACTION_NONE:
       LOG ("ephy_download_do_download_action: none");
@@ -632,16 +633,6 @@ download_decide_destination_cb (WebKitDownload *wk_download,
                                 const gchar    *suggested_filename,
                                 EphyDownload   *download)
 {
-  if (download->in_document_mode) {
-    g_autofree gchar *tmp_file = g_strdup_printf ("%s/%s", g_get_user_cache_dir (), suggested_filename);
-    g_autofree gchar *file_uri = g_filename_to_uri (tmp_file, NULL, NULL);
-
-    webkit_download_set_allow_overwrite (wk_download, TRUE);
-    webkit_download_set_destination (wk_download, file_uri);
-
-    return TRUE;
-  }
-
   if (webkit_download_get_destination (wk_download))
     return TRUE;
 
@@ -824,9 +815,3 @@ ephy_download_disable_desktop_notification (EphyDownload *download)
 
   download->show_notification = FALSE;
 }
-
-void
-ephy_download_enable_evince_document_mode (EphyDownload *download)
-{
-  download->in_document_mode = TRUE;
-}
